/* 

Reported vs. Revealed preference analysis of CE data.

Based on Parker, Souleles, Johnson, McClelland AER regression replication file 
        Merged with SSquest.dta and flagl2iespmissMJJ.dta
              
Key regressors: 
	esp is amount of ESP in period
	iesp is indicator, l means lagged value, l2 means twice lagged
Weight is number of households represented.
 
*/

********************************************************************************
* #0 Program Setup
******************************************************************************** 
set more 1
clear
set mem 200m
set matsize 800
cap log close
cap program drop _all
log using ..\log\RR_CE_regressions.log, replace text
#delimit ;


********************************************************************************
* #1 Create Dataset
******************************************************************************** ;
use ..\data\PSJMReplication.dta, clear;
sort newid ;
merge m:1 newid using ..\data\SSquest.dta, keep(1 3) nogen;

sort newid intview ;
merge 1:1 newid intview using ..\data\flagl2iespmissMJJ.dta, keep(3) nogen ;
sum weight;

sort newid income ;
assert income == income[_n-1] if newid==newid[_n-1] ;
assert liqassii == liqassii[_n-1] if newid==newid[_n-1] ;

quietly quietly tab yymm, gen(ym);
drop ym1 ;

gen samplerprp = baselines3 & flagl2iespmissMJJ ~= 1 ;
tab samplerprp baselines3;

**drop data not used    
tab2 howused samplerprp, mi co ;
drop if samplerprp~=1 ;
sort newid intview ;

program lagsum ;
    /* input is 
        - 1-3 three variables: esp, lesp, and l2esp or iesp liesp and l2iesp 
			or same with spend, nspend, save or payd
        - 4 one word title for column
        - 5 One word title for table
        - 6 one filename: output file for contemp, lagged and cumulative effects 
        - 7 replace or append */ ;
    * Calculated distributed lag effects of spending and cumulative spending following regression;
    args 1 2 3 4 5 6 7 ;
    local contemp`1'=_b[`1'] ;     local contemp`1'se=_se[`1'] ; 
    lincom `1'+`2'  ;
    local lag`1'=r(estimate) ;     local lag`1'se=r(se) ; 
    lincom `1'+`2'+`3'  ;
    local lag2`1'=r(estimate) ;     local lag2`1'se=r(se) ; 

    lincom 2*`1'+`2'  ;
    local cum2`1'=r(estimate) ;     local cum2`1'se=r(se) ; 
    lincom 3*`1'+2*`2'+`3'  ;
    local cum3`1'=r(estimate) ;     local cum3`1'se=r(se) ;     
    outreg2 `1' `2' `3' using `6'.out, dec(3) se noast ctitle(`4') nocons nolabel `7' title(`5')
        addstat(TestSeqNS,$seqnspvalue,Contemp,`contemp`1'',SE,_se[`1'],Lag, `lag`1'',LSE, `lag`1'se',Lag2,`lag2`1'',L2SE, `lag2`1'se',Cum2, `cum2`1'', C2SE, `cum2`1'se',Cum3,`cum3`1'',C3SE, `cum3`1'se') ;
end ;
*`contemp`1'se';
global seqnspvalue = 0 ;


********************************************************************************
* #2 Appendix 2 Panel A: Baseline regressions
******************************************************************************** ;
*Change log changes so that the tables are in percent;
replace dlcn = 100*dlcn ;
replace dlctsmed = 100*dlctsmed ;

*Column 1: "Dollars spent during Period" ;
	* (first line of this regression outputs 1st row) ;
	areg dcn iesp age dnad dnkd  liesp l2iesp [aw=weight] 
		if samplerprp, cluster(newid) a(yymm);
	* (outputs 2nd, 3rd, and 4th row) ;
	lagsum iesp liesp l2iesp NDInd Table3 CETable3 replace;

*Column 2: "Avg. percent increase in spending during period" ;	
	* (1st line of this regression outputs 1st row) ;
	areg dlcn iesp age dnad dnkd  liesp l2iesp [aw=weight] 
		if samplerprp, cluster(newid) a(yymm);

	* (outputs 2nd, 3rd, and 4th row) ;
	lagsum iesp liesp l2iesp lNDInd Table3 CETable3 append;

*Column 3: "Percent of Payment spent during Period"
	* (1st line of this regression outputs 1st row in decimals) ;
	ivreg dcn age dnad dnkd ym* (esp lesp l2esp = iesp liesp l2iesp) [aw=weight] 
		if samplerprp, cluster(newid);

	* (outputs 2nd, 3rd, and 4th row in decimals) ;
	lagsum esp lesp l2esp NDMPC Table3 CETable3 append;


********************************************************************************
* #3 Appendix A Panel B: Baseline regressions
******************************************************************************** ;	
*Column 1: "Dollars spent during Period" ;
	* (first line of this regression outputs 1st row) ;
	areg dctsmed iesp  age dnad dnkd  liesp l2iesp [aw=weight] 
		if samplerprp, cluster(newid) a(yymm);

	* (outputs 2nd, 3rd, and 4th row) ;
	lagsum iesp liesp l2iesp TotInd Table3 CETable3 append;


*Column 2: "Avg. percent increase in spending during period" ;
	*(1st line of this regression ouputs 1st row) ;
	areg dlctsmed age dnad dnkd iesp liesp l2iesp [aw=weight] 
		if samplerprp, cluster(newid) a(yymm);
		
	* (outputs 2nd, 3rd, and 4th row) ;	
	lagsum iesp liesp l2iesp lTotInd Table3 CETable3 append;	
		
*Column 3: "Percent of Payment spent during Period"
	* (1st line of this regression outputs 1st row in decimals) ;	
	ivreg dctsmed age dnad dnkd ym* (esp lesp l2esp = iesp liesp l2iesp) [aw=weight] 
		if samplerprp, cluster(newid);

	* (outputs 2nd, 3rd, and 4th row in decimals) ;
	lagsum esp lesp l2esp TotMPC Table3 CETable3 append;


********************************************************************************
* #4 Table 3 Panel A: Revealed spending by reported spending
******************************************************************************** ;		
* 2. Revealed spending by reported spending -- Table 2 in AER Insights version ;
	* Set up distributed lags interacted with howused ;
	gen allhh=samplerprp ;	
	foreach var in esp lesp l2esp iesp liesp l2iesp	{;
		gen spend`var'= (howuse==1)*`var' ;
		gen nspend`var'= (howuse~=1)*`var' ;
		gen save`var'= (howuse==2)*`var' ;
		gen payd`var'= (howuse==3)*`var' ;
		} ;

	*set locals ;
	local regsamp = "allhh" ;
	  foreach var in spend nspend save payd {;
		local dl`var'esp = "`var'esp `var'lesp `var'l2esp" ;
		local dl`var'iesp = "`var'iesp `var'liesp `var'l2iesp" ;
		} ;
	local howspendesp = "`dlspendesp' `dlnspendesp'" ;
	local howusedesp= "`dlspendesp' `dlsaveesp' `dlpaydesp'" ;
	local howspendiesp = "`dlspendiesp' `dlnspendiesp'" ;
	local howusediesp= "`dlspendiesp' `dlsaveiesp' `dlpaydiesp'" ;
  
	foreach cons in n tsmed {;

	*local for display purposes
	local panel = cond("`cons'"=="n",		"A",
				cond("`cons'"=="tsmed",	"B",
				"ERROR"))	;

	di "
*Panel `panel' Row 1:

	*'spendiesp' line = 1st column of output 
	*'nspendiesp' line = 2nd column of output " ;
	areg dc`cons' `howspendiesp' age dnad dnkd  [aw=weight] 
		if `regsamp', cluster(newid) a(yymm);
    
	di "
	*'Prob > F' = 3rd column of output " ;
	test spendiesp=nspendiesp ;
   
   *not sure what these are used for yet ;
   global seqnspvalue=r(p) ;
    lagsum `dlspendiesp' `cons'IndSp2 `regsamp'`cons'PA CE`regsamp'`cons' replace;
    lagsum `dlnspendiesp' `cons'IndNS `regsamp'`cons'PA CE`regsamp'`cons' append;
   

	*'saveiesp' line = 4th column of output ;
	*'paydiesp' line = 5th column of output ;
	areg dc`cons' age dnad dnkd `howusediesp' [aw=weight] 
		if `regsamp', cluster(newid) a(yymm);
   
   *not sure what these are used for yet ;
   lagsum `dlsaveiesp' `cons'IndSv `regsamp'`cons'PA CE`regsamp'`cons' append;
   lagsum `dlpaydiesp' `cons'IndPd `regsamp'`cons'PA CE`regsamp'`cons' append;
   lagsum `dlspendiesp' `cons'IndSp `regsamp'`cons'PA CE`regsamp'`cons' append;
    
*Panel `panel' Row 2:

	*'spendiesp' line = 1st column of output ;
	*'nspendiesp' line = 2nd column of output ;
	areg dlc`cons' age dnad dnkd `howspendiesp' [aw=weight] 
		if `regsamp', cluster(newid) a(yymm);
   
   *'Prob > F' = 3rd column of output ;
   test spendiesp=nspendiesp ;

   *not sure what these are used for yet ;
   global seqnspvalue=r(p) ;
   lagsum `dlspendiesp' l`cons'IndSp2 `regsamp'`cons'PB CE`regsamp'`cons' append;
   lagsum `dlnspendiesp' l`cons'IndNS `regsamp'`cons'PB CE`regsamp'`cons' append;
    
	*'saveiesp' line = 4th column of output ;
	*'paydiesp' line = 5th column of output ;
	areg dlc`cons' age dnad dnkd `howusediesp' [aw=weight] 
		if `regsamp', cluster(newid) a(yymm);
   
	*not sure what these are used for yet ;
	lagsum `dlsaveiesp' l`cons'Indsv `regsamp'`cons'PB CE`regsamp'`cons' append;
    lagsum `dlpaydiesp' l`cons'IndPd `regsamp'`cons'PB CE`regsamp'`cons' append;
    lagsum `dlspendiesp' l`cons'IndSp `regsamp'`cons'PB CE`regsamp'`cons' append;
    
*Panel `panel' Row 3: 

	*'spendesp' line = 1st column of output ;
	*'nspendesp' line = 2nd column of output ;
    ivreg dc`cons' age dnad dnkd ym* (`howspendesp' = `howspendiesp') [aw=weight] 
		if `regsamp', cluster(newid);
   
	*'Prob > F' = 3rd column of output ;
	test spendesp=nspendesp ;
    
	*NA ;
	global seqnspvalue=r(p) ;
    lagsum `dlspendesp' `cons'MPCSp2 `regsamp'`cons'PC CE`regsamp'`cons' append;
    lagsum `dlnspendesp' `cons'MPCNS `regsamp'`cons'PC CE`regsamp'`cons' append;
    
	*'saveesp' line = 4th column of output ;
	*'paydesp' line = 5th column of output ;
	ivreg dc`cons' age dnad dnkd ym* (`howusedesp' = `howusediesp') [aw=weight]
		if `regsamp', cluster(newid);
    
	*NA ;
	lagsum `dlsaveesp' `cons'MPCSv `regsamp'`cons'PC CE`regsamp'`cons' append;
    lagsum `dlpaydesp' `cons'MPCPd `regsamp'`cons'PC CE`regsamp'`cons' append;
    lagsum `dlspendesp' `cons'MPCSp `regsamp'`cons'PC CE`regsamp'`cons' append;
  } ;

* 3. Income splits ;
sort newid intview ;
sum income [aw=weight] if samplerprp & newid~=newid[_n-1], d ;
_pctile income [aw=weight] if samplerprp & newid~=newid[_n-1], p(30 33 66 70);
ret list;

gen income3=.;
replace income3 = 1 if income<35000 & income~=. ;
replace income3 = 2 if income>=35000 & income<70000 & income~=. ;
replace income3 = 3 if income>=70000 & income~=. ;
gen low3inc = income3==1 & samplerprp ;
gen mid3inc = income3==2 & samplerprp ;
gen high3inc = income3==3 & samplerprp ;
gen income3samp=(income3~=.) ;

table income3, c(mean income n income) ;

foreach incsample in low3inc mid3inc high3inc { ;
    ivreg dcn age dnad dnkd ym* (esp lesp l2esp = iesp liesp l2iesp) [aw=weight] if `incsample', cluster(newid);
    lagsum esp lesp l2esp NDMPC nondur CETab4inc append;
    ivreg dctsmed age dnad dnkd ym* (esp lesp l2esp = iesp liesp l2iesp) [aw=weight] if `incsample', cluster(newid);
    lagsum esp lesp l2esp TotMPC ctsmed CETab4inc append;
    };


* 4. Liquid asset splits ; 
sort newid intview ;
sum liqassii [aw=weight] if samplerprp & newid~=newid[_n-1], d ;
_pctile liqassii [aw=weight] if samplerprp & newid~=newid[_n-1], p(30 33 66 70);
ret list;

gen liqassii2=. ;
replace liqassii2 = 1 if liqassii<2000 & liqassii~=. ;
replace liqassii2 = 2 if liqassii>=2000 & liqassii~=. ;
gen low2liq = liqassii2==1 & samplerprp ; 
gen high2liq = liqassii2==2 & samplerprp ;
gen liqassii2samp=(liqassii2~=.) ;

table liqassii2, c(mean liqassii n liqassii) ;

foreach liqsample in low2liq high2liq { ;
    ivreg dcn age dnad dnkd ym* (esp lesp l2esp = iesp liesp l2iesp) [aw=weight] if `liqsample', cluster(newid);
    lagsum esp lesp l2esp NDMPC nondur CETab4liq append;
    ivreg dctsmed age dnad dnkd ym* (esp lesp l2esp = iesp liesp l2iesp) [aw=weight] if `liqsample', cluster(newid);
    lagsum esp lesp l2esp TotMPC ctsmed CETab4liq append;
    };

log close; 

********************************************************************************
* #6 Table 5 : Reported Spending Behavior by Income & Liquidity
******************************************************************************** ;
gen int intwgt = trunc(weight) ;
sort newid intview ;
drop if weight==. ;
drop if newid==newid[_n-1] ;

log using ..\log\RR_CE_Table5.txt, text replace ;

* Households w/ Income Data ;
	tab income3 [fw=intwgt] ;
	
	*Households w/ Wealth Data ;
    tab liqassii2 [fw=intwgt];

* Households w/ Income Data ;
    tab2 income3 howused [fw=intwgt] if howused<=3, nof row ;
	
	*Households w/ Wealth Data ;
    tab2 liqassii2 howused [fw=intwgt] if howused<=3, nof row ;

	*Summary Stats for Number of Observations ;
	sum income3 liqassii2 if howused<=3 ;

log close ;

