/* Survey Files Cleaning

Infiles: the survey .csv files from AC Nielsen
Outfiles: ESP2008Prog1c.dta  -- main data
            onlinew?p?, paperw?1p? -- intermediate files of survey data
           ESPSumAmount1c.raw -- ascii file of distribution of ESP amounts in 21
                bins 1-299, 300, 301-599, 600, ... 2701-2999, 3000, 3000+ 

Note: lots of missing days with seemingly valid month (ie May)

Overview:

    1. Read in the survey responses for mail and on-line surveys 
            Delete semi-answers that follow reports of no ESP received
    2. Make worksheet for valid responses that will get weights from AC Nielsen
    3. Tabulate and make variables and set flags

    Warning: all statistics are unweighted
 
 In part 1: 
     a.	It erases all information that follows a report of not getting an ESP. There are a few cases 
        with such information, but this information is always so incomplete as to be unusable.
    b.	Question 6 which is the lead-in did you get a rebate question is kept separate for each wave, 
        so we have qn6w1, qn6w2, and qn6w3. (Remember on-line had three wave, paper had two).
    c.	For some mail surveys, households filled out both completely since they scanned in the first 
        after the second was in the mail.  For these 40 households, I use wave1 part 1 data, and take 
        part 2 from wave 2 only if (qn6~=1 and qn6~=4) in wave 1.
    d.	It creates variables that show which wave part1 and part 2 were answered in: wavep1 and wavep2. 
        A bunch have missing wavep2 if they never got to part 2.
    e.	It creates a variable with the survey submit date for part1 and for part 2: surveysubmitdatep1 
        surveysubmitdatep2. A bunch have missing surveysubmitdatep2 if they never got to part 2.
    f.	It creates month, day, amount and rebdate. Amount is missing if 0. Rebdate has format 8mmdd, 
        and is missing if month or day is missing.

In part 2: we set the sample for our weights
    a.  We use households who received (1) or sure not (4) or (expect to (2) in a non-final survey)
        this includes a fair number of hh who do not ever have a response of got a rebate(1) or will not(4)
    b.  For paper, we are keeping 454 who say they are expecting to receive and then do not answer 
        wave 2 and 782-454=328 who answer wave 2 clueless because we may use them when they are 
        confident they will receive
    c.  For online, we are keeping 2433 who say they are expecting to receive in wave 1 and then never get
        or become certain they will not. Of these, 898 remain thinking they will in wave2 and 486 think they
        will in wave 3. In wave 2, 117 of the previously confused answer that they think they will get an ESP. 
    d.  Decide not to keep those who start cluless in wave 1 and then think they will get one in wave 2 and 
        then do not get one or realize they will not in wave 3.  At best these are folks getting it late.

In part 3: we generate flags
*/

********************************************************************************
* #0 Program Setup
********************************************************************************
clear 
set more 1
set memory 100m
capture log close
#delimit ;
log using ../log/NCP02.log, text replace ;


********************************************************************************
* #1 Survey Cleaning
********************************************************************************

*** 1. Read in data ************************************************** ;
/*           survey 280556 "Online Wv 1 pts 1 & 2" 
                    280560 "Online Wv 2 pt 2 only" 
                    280683 "Online Wv 2 pts 1 & 2"
                    280756 "Online Wv 3 pts 1 & 2"
                    280757 "Online Wv 3 pt 2 only"     

                    280532 "Mail Wv 1 pts 1 & 2"  
                    280534 "Mail Wv 2"  ;
                    280599 "Mail Wv 2 pts 1 & 2" */

** First, in July, they sent combined file for on-line waves 1 and 2 and mail 
    *wave 1 that "wrote over" the information about when the wave 2 data was 
    *collected. To recover this information, we must set up wave1 & wave2 separately ;
   
** Set up on-line wave 2 part 2 that is complete as separately sent ;
insheet using ../data/n280560_taxrebate_may08_wv2_part2_fnldat.csv, clear comma ;
rename surveysubmitdate surveysubmitdatep2 ;
replace surveysubmitdatep2 = . if qn6~=1 & qn6~=4 ;
rename qn6 qn6w2 ; 
label variable qn6w2 "Qn6 wave 2" ;
gen wavep2=2 if qn6w2==1 | qn6w2==4 ;
sort householdid ;
* Check that no data follows a report of no to question 6 ;
sum householdid wave* qn6* qn7a qn8a qn8-qn10 if qn6w2~=1 ;
save ../data/onlinew2p2, replace ;


** Check the July datasets and Investigate the overwriting ;
insheet using ../data/n280556_taxrebate_may08_cum_fnldat.csv, clear comma ;
/* This first file is an aggregation of 
    280556 (online, wave 1 parts 1 and 2), 280532 (mail wave 1 parts 1 and 2)
	280683 (online, wave 2 parts 1 and 2), 280560 (online wave 2 part 2 only) */ ;
	
label define qn6 1 "Yes"  2 "No, but we are expecting to" 3 "No, but we are unsure that we will get any" 
    4 "No, and we are definitely not getting one" 5 "Not sure/dont know" ;
label list qn6 ;
tab qn6 survey, column label mi ;

* Keep  online wave 1 parts 1 and 2 but containing wave 2 part 2 if exists ;
keep if survey==280556 ;
* Check that no data follows a report of no to question 6 ;
gen qn6inbigdata = qn6 ;
gen ssdateinbigdata = surveysubmitdate ;
keep householdid qn6inbigdata ssdateinbigdata;
sort householdid ;
save ../data/temp, replace ;

insheet using ../data/n280560_taxrebate_may08_wv2_part2_fnldat.csv, clear comma ;
* Already saw above that no invalid data follows qn6~=1  ;
sort householdid ;

merge householdid using ../data/temp ;
tab _merge ;
* So no households in just 280560 that is none only in wv 2 part 2 ;
tab qn6 qn6inbigdata if _merge==3,  label mi ; 
* So in both datasets, the qn6 answers are same, so repeats all come from wv 2 ;
tab qn6 qn6inbigdata if _merge==2, mi ;
* So in just the bigdataset, there is no qn6 data in the wave 2 dataset ;
* Conclude that if we use the big first dataset, gen part 1 date= date and then 
    overwrite with the wave 2 part 2 only we get the correct wave2 date. ;
* Check out the survey date ;
sum surveysubmitdate ssdateinbigdata ;
* So nonoverlapping means that data in bigdata obs listed as 280560 is for wave 1 ;


** Set up a file for 556, online wave 1 parts 1 and 2 ;
use ../data/onlinew2p2, clear ;
keep householdid ;
sort householdid ; 
save ../data/temp, replace ;

insheet using ../data/n280556_taxrebate_may08_cum_fnldat.csv, clear comma ;
keep if survey==280556 ;

* Get rid of answers following response: did not get ESP ;
gen temp=real(qn8a) ; drop qn8a ; rename temp qn8a ;
sum householdid qn6* qn8a qn7-qn10 if qn6~=1 ;
replace qn8a=. if qn6~=1 ;
replace qn7a=. if qn6~=1 ;

sort householdid ;
* temp is householdid only from onlinew2p2 sorted by householdid ;
merge householdid using ../data/temp ;
tab _merge ;
sum ;
sum householdid qn6* qn7a qn8a qn8-qn10 if qn6~=1 ; 

* Now make all part 2 information missing if merge==3 that is, if part 2 information is from wave 2;
local v "qn7 qn7a qn8 qn8a qn9 qn10 qn11_1 qn11_2 qn11_3 qn11_4 qn11_5" ;
tokenize "`v'" ;
 local i 1 ;
 while "``i''" != "" { ;
     di "``i''" ;
     replace ``i''=. if _merge==3 ;
    local i = `i' + 1 ;
    } ;
drop _merge ;
sum ;
sort householdid ;

* Check that no valid data following a report of no to question 6 ;
save ../data/temp, replace ; 

insheet using ../data/280556_TaxRebate_wave1_whatonQ6.csv, clear comma ;
sum ;
rename hhldidnumber householdid ;
rename qn6 qn6wave1 ;
keep householdid qn6wave1 ;
label variable qn6wave1 "qn6wave1" ;
sum ;
sort householdid ;
merge householdid using ../data/temp ;
tab _merge ;
tab qn6 qn6wave1 if _merge==2, mi ;
tab qn6 qn6wave1 if _merge==3, mi ;
replace qn6=qn6wave1 if _merge==3 ;
drop _merge qn6wave1 ;
rename surveysubmitdate surveysubmitdatep1 ;
gen surveysubmitdatep2 = surveysubmitdatep1 if qn6==1 | qn6==4 ;
gen wavep1=1 ;
gen wavep2=1 if qn6==1 | qn6==4 ;
sort householdid ;
sum ;
* Check that no valid data following a report of no to question 6 ;
sum householdid qn8a qn7a ;
sum householdid qn6* qn7a qn8a qn7-qn10 if qn6~=1 ;
save ../data/onlinew1p12, replace ;


** Second, read in all the rest of the data, starting with on-line ;
** On-line first   (just above is onlinew1p12) ;
insheet using ../data/n280556_taxrebate_may08_cum_fnldat.csv, clear comma ;
keep if survey==280683 ; /* on-line wave2 parts 1 and 2 */
* Get rid of answers following response: did not get ESP ;
gen temp=real(qn8a) ; drop qn8a ; rename temp qn8a ;
sum householdid qn6* qn8a qn7-qn10 if qn6~=1 ;
replace qn8a=. if qn6~=1 ;
replace qn7a=. if qn6~=1 ;

rename surveysubmitdate surveysubmitdatep1 ;
gen surveysubmitdatep2 = surveysubmitdatep1 if qn6==1 | qn6==4 ;
rename qn6 qn6w2 ; 
label variable qn6w2 "Qn6 wave 2" ;
gen wavep1=2 ;
gen wavep2=2 if qn6w2==1 | qn6w2==4 ;
sum ;
sort householdid ;
save ../data/onlinew2p12, replace ;


** On-line wave3 parts 1 and 2 ;
insheet using ../data/n280756_taxrebate_may08_wv3_fnldat.csv, clear comma ;
* Check that no data follows qn6~=1 ;
sum householdid qn8a qn7a ;
sum householdid qn6* qn7a qn8a qn7-qn10 if qn6~=1 ;
rename surveysubmitdate surveysubmitdatep1 ;
gen surveysubmitdatep2 = surveysubmitdatep1 if qn6==1 | qn6==4 ;
rename qn6 qn6w3 ; 
label variable qn6w3 "Qn6 wave 3" ;
gen wavep1=3 ;
gen wavep2=3 if qn6w3==1 | qn6w3==4  ;
sum ;
sort householdid ;
save ../data/onlinew3p12, replace ;


** On-line wave 3 part 2 only ;
insheet using ../data/n280757_taxrebate_may08_wv3_fnldat.csv, clear comma ;
* Fix data follows qn6~=1 ;
sum householdid qn8a qn7a ;
sum householdid qn6* qn7a qn8a qn7-qn10 if qn6~=1 ;
replace qn8a=. if qn6~=1 ;
* NOTE: FIXED erroneous observation with qn6 data messed up in .csv file but not .xls file ;
**drop if householdid== 2002996  -- actually has qn6=3 ;
*gen qn6w3=real(qn6) ; *drop qn6 ; 
rename qn6 qn6w3 ;
assert qn6w3>0 & qn6w3<6 ;
rename surveysubmitdate surveysubmitdatep2 ;
replace surveysubmitdatep2 = . if qn6w3~=1 & qn6w3~=4 ;
label variable qn6w3 "Qn6 wave 3" ;
gen wavep2=3 if qn6w3==1 | qn6w3==4  ;
sum ;
sort householdid ;
save ../data/onlinew3p2, replace ;


*** Merge the online datasets ;
use ../data/onlinew1p12, clear ;
drop survey ;
sort householdid ;
merge householdid using ../data/onlinew2p2, update unique ;
tab _merge ; 
* _merge == 1 are those just in wave 1 ;
* _merge==3 is the households who in wave 2 only answer qn6w2 ~= (1 or 4) ;
* _merge==4    obs. from both, missing in master updated 
    is the overwriting of wavep2=2 for those with qn6w2 = (1 or 4) ;
tab qn6 qn6w2 if _merge==3, mi ;
tab qn6 qn6w2 if _merge==4, mi ; 
* Should have qn6~= (1 or 4) if qn6w2~=. and ideally qn6==qn6w2 if qn6w2>1 and not missing ;
drop _merge survey ;

sort householdid ;
merge householdid using ../data/onlinew2p12, update unique ;
tab _merge ; * should have no threes -- nonoverlapping samples ;
drop _merge survey ;
sort householdid ;
merge householdid using ../data/onlinew3p12, update unique ;
tab _merge ;
* Should have no threes -- nonoverlapping samples ;
drop _merge survey ;
* Fix one erroneous zero rebate amount from wave 2 ;
list householdid surveysubmit* wavep1 wavep2 qn1 qn6  qn6w2 qn8a qn8  if householdid==30068740 ;
list householdid surveysubmit* wavep1 wavep2 qn1 qn6  qn6w2 qn6w3 qn8a qn8  if qn6~=1 & qn6w2~=1 & qn6w3~=1 & qn8~=. ;
replace qn8a=. if householdid == 30068740 ;

sort householdid ;
merge householdid using ../data/onlinew3p2, update unique ;
tab _merge ;
tab qn6 qn6w3 if _merge==4, mi ;
* Should have qn6~=1 if qn6w3~=. and ideally qn6==qn6w3 if qn6w3>1 and not missing ;
tab qn6w2 qn6w3 if _merge==4, mi ;
* Should have qn6w2~=1 if qn6w3~=. and ideally qn6w2==qn6w3 if qn6w3>1 and not missing ;
drop _merge survey ;
gen online=1 ;
sort householdid ;
save ../data/onlinetemp, replace ;


** Now paper, read in first  ;
insheet using ../data/n280556_taxrebate_may08_cum_fnldat.csv, clear comma ;
tab survey ;
* Keep only the mail first wave ;
keep if survey==280532 ;
* Fix data follows qn6~=1 ;
gen temp=real(qn8a) ; drop qn8a ;
rename temp qn8a ;
sum householdid qn8a qn7a ;
sum householdid qn6* qn8a qn7-qn10 qn11* if qn6~=1 ;
replace qn7a=. if qn6~=1 ;
replace qn8a=. if qn6~=1 ;
replace qn11_1=. if qn6~=1 ;
replace qn11_2=. if qn6~=1 ;
replace qn11_3=. if qn6~=1 ;
replace qn11_4=. if qn6~=1 ;
replace qn11_5=. if qn6~=1 ;
* more ;

rename surveysubmitdate surveysubmitdatep1 ;
gen surveysubmitdatep2 = surveysubmitdatep1 if qn6==1 | qn6==4 ;
gen wavep1=1 ;
gen wavep2=1 if qn6==1 | qn6==4 ;
sum ;
sort householdid ;
save ../data/paperw1p12, replace ;

* Warning this file has incorrect survey number -- listed as 280532 when it should be 280599 ;
insheet using ../data/n280599_taxrebate_ppr_wv2_fnldat.csv, clear comma ;
* Fix data follows qn6~=1 ;
sum householdid qn8a qn7a ;
sum householdid qn6* qn7-qn10 qn11* if qn6~=1 ;
replace qn7a=. if qn6~=1 ;
replace qn8a=. if qn6~=1 ;
replace qn11_1=. if qn6~=1 ;
replace qn11_2=. if qn6~=1 ;
replace qn11_3=. if qn6~=1 ;
replace qn11_4=. if qn6~=1 ;
replace qn11_5=. if qn6~=1 ;
*more ;
sum survey ;
replace survey=280599 ;
rename surveysubmitdate surveysubmitdatep1 ;
gen surveysubmitdatep2 = surveysubmitdatep1 if qn6==1 | qn6==4 ;
rename qn6 qn6w2 ; 
label variable qn6w2 "Qn6 wave 2" ;
gen wavep1=2 ;
gen wavep2=2 if qn6w2==1 | qn6w2==4 ;
sum ;
sort householdid ;
*** WARNING: data file overwritten below in merging section ;
save ../data/paperw2p12, replace ;

insheet using ../data/n280534_taxrebate_ppr_wv2_fnldat.csv, clear comma ;
* Check no data follows qn6~=1 ;
sum householdid qn8a qn7a ;
sum householdid qn6* qn7-qn10 qn11* if qn6~=1 ;
*more ;
* drop the one household who seemed to have gotten into wave 2 for parts 1 and 2 and part 2 only;
drop if householdid==02101507 ;

rename surveysubmitdate surveysubmitdatep2 ;
replace surveysubmitdatep2 = . if qn6~=1 & qn6~=4 ;
rename qn6 qn6w2 ; 
label variable qn6w2 "Qn6 wave 2" ;
gen wavep2=2 if qn6w2==1 | qn6w2==4 ;
sum ;
sort householdid ;
save ../data/paperw2p2, replace ;


** Merge the paper datasets ;
* Problem 1:  40 households responded twice to the complete mail survey and a 
    *few responded in wave2 part 2 as well as wave 1;
use ../data/paperw1p12, clear ;

sort householdid ;
merge householdid using ../data/paperw2p12, unique ;
tab _merge ; * should have no threes -- nonoverlapping samples, but in fact . . .  ;
keep if _merge==3 ;
keep householdid qn6 ;
sort householdid ;
save ../data/temp, replace ;

* Keep wave1 survey 1 data, and take survey 2 wave 2 whenever (qn6~=1 and qn6~=4) ;
use ../data/paperw2p12, clear ;
sum if qn6w2~=1 ;
sort householdid ;
merge householdid using ../data/temp, unique ;
tab _merge ;

* get rid of part 1 data in wave 2 for hh in wave 1;
local v "wavep1 surveysubmitdatep1 qn1 qn2 qn3 qn4 qn5" ;
tokenize "`v'" ;
 local i 1 ;
 while "``i''" != "" { ;
     di "``i''" ;
     replace ``i''=. if _merge==3 ;
    local i = `i' + 1 ;
    } ;

* get rid of part 2 wv 2 data when it would/should not have been asked or when wave 1 had qn6==1;
local v "wavep2 surveysubmitdatep2 qn7 qn7a qn8 qn8a qn9 qn10 qn11_1 qn11_2 qn11_3 qn11_4 qn11_5" ;
tokenize "`v'" ;
 local i 1 ;
 while "``i''" != "" { ;
     di "``i''" ;
     replace ``i''=. if _merge==3 & (qn6==1 | qn6==4 | qn6w2==1 | qn6w2==4) ;
    local i = `i' + 1 ;
    } ;
replace qn6w2=. if _merge==3 & (qn6==1 | qn6==4) ;

drop _merge survey qn6 ;
sort householdid ;
save ../data/paperw2p12, replace ;
sum if qn6~=1 & qn6w2~=1 ;
* more ;
use ../data/paperw1p12, clear ;
sum if qn6~=1 ;
*more ;
sort householdid ;
drop survey ;
merge householdid using ../data/paperw2p12, update replace unique ;
* update replace writes over informatiom in the master with the using but wont make missing ;
tab _merge ;
* _merge==3 and 4 is our 40 duplicate households ;
tab qn6w2 qn6 if _merge>2, mi ;
* So 13 people went from "expecting to" to "got it" ;
drop _merge  ;
sum if qn6~=1 & qn6w2~=1 ;
* more ;
sort householdid ;
merge householdid using ../data/paperw2p2, update replace unique ;
tab _merge ;
* _merge==2 is one household (8025560) who is only in wave 2 part 2 only  ;
* _merge==4 is the people whose missing data is being overwritten with part 2 suvey info ;
* _merge==5 is 10 people in wave 1 who answered part 1 and qn6~=1 and 
        *still answered questions 11 and 7a -- want to overwrite ;
list householdid wavep1 qn6 qn6w2 qn7 qn7a qn8 qn9 if _merge==5 ;
*more ;
sum if _merge==2 ;
sum if qn6~=1 & qn6w2~=1 ;
drop _merge survey ;
gen online=0 ;
sum  ;

* Add back in the on-line ;
sort householdid ;
merge householdid using ../data/onlinetemp, update unique ;
tab _merge ;
drop _merge ;

sort householdid ;
save ../data/ESP2008Prog1c, replace ;



*** 2. Sample of valid responses for weights ********************************************* ;
tab qn6w2 qn6w3 if qn6~=1 & qn6~=2 &qn6~=4, mi ;
tab qn6w3 if qn6~=1 & qn6~=2 &qn6~=4 & qn6w2~=1 & qn6w2~=2 &qn6w2~=4, mi ;

* Use households who received (1) or sure not (4) or (expect to (2) in a non-final survey) ;
gen use=1 if (qn6==1 | qn6==2 | qn6==4) | 
            ((qn6w2==1 | qn6w2==4) & online==0) | 
            ((qn6w2==1 | qn6w2==2 | qn6w2==4) & online==1) | 
            (qn6w3==1 | qn6w3==4) ;

tab qn6w2 qn6w3 if (qn6==. | qn6==3 | qn6==5) & use==., mi ;
sum householdid qn7 qn7a if use==1 & (qn6==1 | qn6w2==1 | qn6w3==1) ;
* So almost everyone who should has a response to date ;

sum householdid qn7 qn7a if use==1 & qn6~=4 & qn6w2~=4 & qn6w3~=4 ;
* So a lot of households are being included who do not aver have a response of got a rebate(1) or will not(4) ;

tab qn6 qn6w2 if online==0 & use==1 & qn6~=1 & qn6w2~=1 & qn6w3~=1 & qn6~=4 & qn6w2~=4 & qn6w3~=4, mi  ;
* So for paper, we are keeping 454 who say they are expecting to receive and then do not answer wave 2 
    *and 782-454=328 who answer wave 2 clueless -- we can use them when they are confident they will receive ;

tab qn6 qn6w2 if online==1 & use==1 & qn6~=. & qn6~=1 & qn6w2~=1 & qn6w3~=1 & qn6~=4 & qn6w2~=4 & qn6w3~=4, mi ;
tab qn6w2 qn6w3 if online==1 & qn6~=. & qn6~=2 & use==1 & qn6~=1 & qn6w2~=1 & qn6w3~=1 & qn6~=4 & qn6w2~=4 & qn6w3~=4, mi ;
* So for online, we are keeping 2433 who say they are expecting to receive in wave 1 and then never get 
    *or become certain they will not. Of these, 898 remain thinking they will in wave2 and 486 think they
    *will in wave 3. In wave 2, 117 of the previously confused answer that they think they will get an ESP ;
** Decide not to keep those who start cluless in wave 1 and then think they will get one in wave 2 and then
    *do not get one or realize they will not in wave 3.  At best these are folks getting it late. ;
tab qn6w3 qn6 if online==1 & use==1 & (qn6==3 | qn6==5) & qn6w2==2 & (qn6w3==2 | qn6w3==3 | qn6w3==5 | qn6w3==.), mi ;
replace use=. if online==1 & (qn6==3 | qn6==5) & qn6w2==2 & (qn6w3==2 | qn6w3==3 | qn6w3==5 | qn6w3==.); 

tab use, mi ;
sum householdid use ;
sum if use==1 ;
sort householdid ;
outfile householdid using ../data/valid_response_households1c.csv if use==1, comma replace ;



*** 3. Look at responses and code up ********************************************* ;
use ../data/ESP2008Prog1c, clear ;
rename householdid hhid ;
sum ;
sort hhid ;
assert hhid~=hhid[_n-1] ;
tab online, mi ;

** QUESTION 6 Check main rebate variable  ;
label define qn6 1 "Yes"  2 "No, but we are expecting to" 3 "No, but we are unsure that we will get any" 
    4 "No, and we are definitely not getting one" 5 "Not sure/dont know" ;
label define qn6w2 1 "Yes"  2 "No, but we are expecting to" 3 "No, but we are unsure that we will get any" 
    4 "No, and we are definitely not getting one" 5 "Not sure/dont know" ;
label define qn6w3 1 "Yes"  2 "No, but we are expecting to" 3 "No, but we are unsure that we will get any" 
    4 "No, and we are definitely not getting one" 5 "Not sure/dont know" ;
label list qn6 ;
tab qn6 qn6w2 if online==0, mi  ;
*Conclude: Every paper guy answers qn6 in one round
    qn6 == 1 or 4 implies qn6wv2==1
    qn6 == 2, 3, 5, or . then get asked qn6wv2  
    some go from expecting (2) to unsure (3 or 5) or sure not getting (4);
tab qn6w2 qn6w3 if online==1 & (qn6==1 | qn6==4), mi  ;  
* Good, no answers for later if start with 1 or 4;
tab qn6w2 qn6w3 if online==1 & qn6==., mi  ;  
tab qn6w2 qn6w3 if online==1 & qn6==2, mi  ;  
tab qn6w2 qn6w3 if online==1 & (qn6==3 | qn6==5 ), mi  ;  
* Note: transitions in what people expect ;

gen gotesp = qn6==1 | qn6w2==1 | qn6w3==1 ;
gen endnotgetting = qn6==4 | qn6w2==4 | qn6w3==4 ;
tab2 gotesp endnotgetting, mi ; * check no overlap ;
drop endnotgetting ;

** PART 1 Tabulate 1 questions  -- pay particular attn to difference on-line and mail
        *Find that mail respondents, fewer go on vacat, spend less time planning if do,
        *lower share regret, are more save for future, more have funds, 
        *more have financial plan  --  AGE DRIVEN? ;

label define qn1 1 "A great deal of time"  2 "Quite a bit of time" 3 "A little time" 
    4 "Almost no time" 5 "Do not go on vacation" ;
label list qn1 ;
tab2 qn1 online, mi column ;
tab2 qn1 online if qn1~=5, mi column ;

label define qn2 1 "Often buy stuff regret"  2 "Occasionally" 3 "Rarely" 4 "Never" ;
label list qn2 ;
tab2 qn2 online, mi column ;

label define qn3 1 "Spend now"  2 "Save for the future" ;
label list qn3 ;
tab2 qn3 online, mi column ;

label define qn4 1 "Yes have funds"  2 "No" ;
label list qn4 ;
tab2 qn4 online, mi column ;

label define qn5 1 "Yes have financial planned"  2 "No" ;
label list qn5 ;
tab2 qn5 online, mi column ;

** PART 2 Tabulate questions ;
sum hhid gotesp ;
* See some missing data after saying got ESP ;
sum hhid qn7* qn8* qn9 qn10 qn11* if gotesp==1 ; 
* check not data for households not answering qn6==1 at some point ;
sum hhid qn7* qn8* qn9 qn10 qn11* if gotesp==0 ;


*** qn7. DATE ;
gen flagdaymissing = qn7a==. | qn7a==1 ;
gen flagmonthmissing = qn7==. ;
sort hhid ;
gen month = qn7+3  ;
label define month 4 "April"  5 "May" 6 "June" 7 "July" ;
label list month ;
tab2 month online, mi column ;

gen day = qn7a -1 ;
label define day 0 "Do not know" ;
tab2 day online, mi ;
tab2 day month if day==0 | day==1, mi ;
* Note can have valid month and missing day;
* also have no May 31 or June 31 ;
gen rebdate = 80000+100*month+day ;
replace rebdate=. if day==0 ;
replace day=. if day==0 ;
tab2 day month if gotesp, mi ;

*tab surveysubmitdatep2 ;
/* c = Continuous dates from 04 01 on. 30 days in 4 and 6, 31 in 5 and 7 and 8.
   surveysubmitdatep2 runs from 080527 to 080909, crebdate rRuns from 80401 to 80731  */
foreach var of varlist surveysubmitdatep2 rebdate surveysubmitdatep1 { ;
    gen c`var' = . ; 
    replace c`var' = `var'-80400
                                if `var'<80501 & `var'~=. ;
    replace c`var' = `var'-80500+30
                                if `var'>=80501 & `var'<=80601;
    replace c`var' = `var'-80600+61 
                                if `var'>=80601 & `var'<80701 ;
    replace c`var' = `var'-80700+91 
                                if `var'>=80701 & `var'<80801 ;
    replace c`var' = `var'-80800+122 
                                if `var'>=80801 & `var'<80901 ;
    replace c`var' = `var'-80900+153 
                                if `var'>=80901 & `var'~=. ;
} ;

sum crebdate csurveysubmitdatep2 ;

* Look at households who report an ESP after submit date ;
gen daysaftersubmit = crebdate-csurveysubmitdatep2 ;
tab2 daysaftersubmit online if csurveysubmitdatep2<=crebdate+7 & crebdate~=. ;
* Similar proportion spilling a little late by mail and b online ;
* On-line ;
tab2 wavep1 wavep2 if surveysubmitdatep2<rebdate & rebdate~=. & online ;
* And by mail ;
tab2 wavep1 wavep2 if surveysubmitdatep2<rebdate & rebdate~=. & online==0 ;

* Look at households who report ESPs they should have reported in previous wave ;
gen daysbeforep1 = csurveysubmitdatep1-crebdate ;
assert wavep2==wavep1 if surveysubmitdatep1==surveysubmitdatep2 ;
assert surveysubmitdatep1==surveysubmitdatep2 if wavep2==wavep1 ;
tab2 daysbeforep1 online if wavep2~=wavep1 & rebdate~=. & daysbeforep1>-7, mi ;
* About 1/18th or 1/7th of folks reporting in different waves report this ;

***** Flag all data with rebate received after reported (with 1 day error) ;
gen flagesp2aftersubmit = crebdate-csurveysubmitdatep2>2 & rebdate~=. ;
***** Flag report in part 2 is date before p1 submitted reporting no ESP (7 day recall error);
gen flagp2esp2beforep1submit = csurveysubmitdatep1-crebdate>2 & wavep2~=wavep1 & rebdate~=. ;
drop daysbeforep1 daysaftersubmit ;

tab flagesp2aftersubmit flagp2esp2beforep1submit if rebdate~=., mi ;
sum gotesp rebdate day month if qn6==1 | qn6w2==1 | qn6w3==1 ;
more;
 
**** set up procrastinator measure days after surveyed when report ESP ;
* Online: 5/27, 6/26 and 7/25,  mailed: 6/13 (rem 6/19) and 7/25 (rem 7/31);
gen daysaftersurveyed = . ;
replace daysaftersurveyed = csurveysubmitdatep2-(30+27) if online & surveysubmitdatep2>=80527 ;
replace daysaftersurveyed = csurveysubmitdatep2-(30+31+26) if online & surveysubmitdatep2>=80626 ;
replace daysaftersurveyed = csurveysubmitdatep2-(30+31+30+25) if online & surveysubmitdatep2>=80725 ;

replace daysaftersurveyed = csurveysubmitdatep2-(30+31+13) if online==0 & surveysubmitdatep2>=80613 ;
replace daysaftersurveyed = csurveysubmitdatep2-(30+31+30+25) if online==0 & surveysubmitdatep2>=80725 ;

replace daysaftersurveyed = max(daysaftersurveyed,-1) if daysaftersurveyed~=. ;
tab2 daysaftersurveyed online, mi ;
sum daysaftersurveyed if online, d ;
sum daysaftersurveyed if online==0, d ;

 
*** qn8. MAIL vs DEPOSIT ;
* The first date the IRS direct deposited any money was April 28 (source DTS) and deposits were to arrive by May 2.
  But banks were notified a few days before and may have creditted the accounts.
  The first week mailed checks were supposed to arrive by the end of was May 16 ;
label define qn8 1 "Direct deposit"  2 "Mail" 3 "Dont know" ;
label list qn8 ;
tab2 qn8 online if gotesp, column mi ;
tab2 rebdate qn8 if gotesp, mi ;
* Observe the direct deposit dist gets second two spikes of: 21% by 5/2, 55% by 5/9 and 24% by 5/16 ;
	* Mailing distribution is 11% per week starting week ending 5/16 and ending week ending 7/11 ;

** Flag all data with rebdate earlier than earliest possible date: 
    *for deposit or unknown, 4/28 less 3 or 7 days for error 
    *for mail assume date is seven days before end of first week date and then allow 3 or 7 days for error ;
gen flagearlyloose = (qn8~=2 & rebdate<80428-7 & gotesp) | (qn8==2 & rebdate<80516-7-7 & gotesp) ;
gen flagearlytight = (qn8~=2 & rebdate<80428-3 & gotesp) | (qn8==2 & rebdate<80516-7-3 & gotesp) ;

** Flag all data with rebdate later than randomized timing: 
    *for deposit 5/16 plus 3 or 7 days for error 
    *for mail or unknown assume date is seven days after mailed by date plus 3 or 7 days for error ;
gen flagelateloose = (qn8==1 & rebdate>80516+7 & gotesp) | (qn8~=1 & rebdate>80711+7+7 & gotesp) ;
gen flagelatetight = (qn8==1 & rebdate>80516+3 & gotesp) | (qn8~=1 & rebdate>80711+7+3 & gotesp) ;


*** 8a. AMOUNT ;
label variable qn8a "Rebate amount" ;
sum qn8a if gotesp, d ;
sum qn8a if gotesp & rebdate~=., d ;

gen amount = qn8a ;
replace amount = . if qn8a==0 ;

statsmat qn8a if qn8a>0 & gotesp & rebdate~=. , stat(count) matrix(SumAmountrow1) ;

statsmat qn8a if qn8a>0 & qn8a<300 & gotesp & rebdate~=. , stat(count) matrix(dummy) ;
matrix SumAmount=(dummy) ;
statsmat qn8a if qn8a==300 & gotesp & rebdate~=. , stat(count) matrix(dummy) ;
matrix SumAmount=(SumAmount\dummy) ;
statsmat qn8a if qn8a>300 & qn8a<600 & gotesp & rebdate~=. , stat(count) matrix(dummy) ;
matrix SumAmount=(SumAmount\dummy) ;
statsmat qn8a if qn8a==600 & gotesp & rebdate~=. , stat(count) matrix(dummy) ;
matrix SumAmount=(SumAmount\dummy) ;
statsmat qn8a if qn8a>600 & qn8a<900 & gotesp & rebdate~=. , stat(count) matrix(dummy) ;
matrix SumAmount=(SumAmount\dummy) ;
statsmat qn8a if qn8a==900 & gotesp & rebdate~=. , stat(count) matrix(dummy) ;
matrix SumAmount=(SumAmount\dummy) ; 
statsmat qn8a if qn8a>900 & qn8a<1200 & gotesp & rebdate~=. , stat(count) matrix(dummy) ;
matrix SumAmount=(SumAmount\dummy) ;
statsmat qn8a if qn8a==1200 & gotesp & rebdate~=. , stat(count) matrix(dummy) ;
matrix SumAmount=(SumAmount\dummy) ;
statsmat qn8a if qn8a>1200 & qn8a<1500 & gotesp & rebdate~=. , stat(count) matrix(dummy) ;
matrix SumAmount=(SumAmount\dummy) ;
statsmat qn8a if qn8a==1500 & gotesp & rebdate~=. , stat(count) matrix(dummy) ;
matrix SumAmount=(SumAmount\dummy) ;
statsmat qn8a if qn8a>1500 & qn8a<1800 & gotesp & rebdate~=. , stat(count) matrix(dummy) ;
matrix SumAmount=(SumAmount\dummy) ;
statsmat qn8a if qn8a==1800 & gotesp & rebdate~=. , stat(count) matrix(dummy) ;
matrix SumAmount=(SumAmount\dummy) ;
statsmat qn8a if qn8a>1800 & qn8a<2100 & gotesp & rebdate~=. , stat(count) matrix(dummy) ;
matrix SumAmount=(SumAmount\dummy) ;
statsmat qn8a if qn8a==2100 & gotesp & rebdate~=. , stat(count) matrix(dummy) ;
matrix SumAmount=(SumAmount\dummy) ;
statsmat qn8a if qn8a>2100 & qn8a<2400 & gotesp & rebdate~=. , stat(count) matrix(dummy) ;
matrix SumAmount=(SumAmount\dummy) ;
statsmat qn8a if qn8a==2400 & gotesp & rebdate~=. , stat(count) matrix(dummy) ;
matrix SumAmount=(SumAmount\dummy) ;
statsmat qn8a if qn8a>2400 & qn8a<2700 & gotesp & rebdate~=. , stat(count) matrix(dummy) ;
matrix SumAmount=(SumAmount\dummy) ;
statsmat qn8a if qn8a==2700 & gotesp & rebdate~=. , stat(count) matrix(dummy) ;
matrix SumAmount=(SumAmount\dummy) ;
statsmat qn8a if qn8a>2700 & qn8a<3000 & gotesp & rebdate~=. , stat(count) matrix(dummy) ;
matrix SumAmount=(SumAmount\dummy) ;
statsmat qn8a if qn8a==3000 & gotesp & rebdate~=. , stat(count) matrix(dummy) ;
matrix SumAmount=(SumAmount\dummy) ;
statsmat qn8a if qn8a>3000 & gotesp & rebdate~=. , stat(count) matrix(dummy) ;
matrix SumAmount=(SumAmount\dummy) ;

mat2txt , matrix(SumAmount) saving(ESPSumAmount1c.raw) replace ;

tab amount if qn8a>3000 ;
gen flagamountgt3000 = amount>3000 ;
gen flagamountgt6000 = amount>6000 ;


*** 9. AMOUNT EXPECTING ;
label define qn9 1 "No, suprised to get any"  2 "No, less than expected" 3 "No, more than expected" 
            4 "Yes, and known since Feb" 5 "Yes, and known since March" 6 "Yes, and known since April"
            7 "Yes, but only learned recently" 8 "Not sure (PAPER ONLY)";
label list qn9 ;
tab2 qn9 online if gotesp, mi column ;
tab2 qn9 online if gotesp & amount~=. & rebdate~=., mi column ;


*** 10. SHAPIRO SLEMROD ;
label define qn10 1 "Mostly to increase spending"  2 "Mostly to increase saving" 3 "Mostly to pay off debt" 
            4 "Not sure/dont know" ;
label list qn10 ;
tab qn10 online if gotesp, mi column;
tab qn10 online if gotesp & amount~=. & rebdate~=., mi column;
* Answering by mail show higher propensity to spend while getting check by mail about the same ;


*** 11. REPORTED SPENDING ;
label variable qn11_1 "Food, health & beauty, household products" ;
label variable qn11_2 "Entertainment, personal services" ;
label variable qn11_3 "Durables" ;
label variable qn11_4 "Clothing, shoes or accessories" ;
label variable qn11_5 "Other" ;
gen totrepspend = qn11_1+qn11_2+qn11_3+qn11_4+qn11_5 ;
sum totrepspend qn11* if gotesp ;

* Look for people spending more than rebate and rebate positive -- NOTE POSSIBLY CORRECT ;
sum totrepspend amount if totrepspend>amount & amount~=. ;
* Look at the rest -- NOTE: some maxed out totals and they come on DURABLES and OTHER like they should;
sum totrepspend amount if totrepspend<=amount & amount>0 & amount~=.;
* Look at everyone ;
summ totrepspend amount qn11* if amount>0 & amount~=. ;
label list qn10 ;
bysort qn10: summ totrepspend amount qn11* if amount>0 & amount~=. ;
* So mostly spend are reporting on average spending it all !! ;
reg totrepspend amount ;
* So reported spending rises with MPC of 37% with actual rebate amount ;

sort hhid ;
save ../data/ESP2008Prog1c, replace ;
label save using ../data/NCP02b_labels_esp.do, replace ;
log close ;
