/* Runs MONTHLY regressions

pct dependent variables are spending over first 12 week/3 month average 
    cutting the bottom 1% of first 12 week/3 month average.

Infile: ../data/rprpNCPprep1c

*/

********************************************************************************
* #0 Program Setup
********************************************************************************
# delimit ;
clear ;
clear matrix ;
program drop _all ;
set more 1 ;
set memory 1500m ;
capture log close ;
log using ../log/rprpNCPMRegs1f.log, text replace ;
 ssc install ivreg2 ;
 ssc install reghdfe ;
 ssc install ranktest ;


********************************************************************************
* #1 Preliminaries
******************************************************************************** ;
use ../data/rprpNCPprep1c, clear ; 
*keep if int(hhid/100)==hhid/100 ;


* Set main sample ;
sum hhid sample2 qn10 qn11* projection_factor ;
keep if sample2 & qn10~=. & qn10~=4 & projection_factor~=. ;
gen samplerprp = sample2 & qn10~=. & qn10~=4 & projection_factor~=. ;

* Key survey variables ;
label define qn10 1 `"Mostly to increase spending"' ;
label define qn10 2 `"Mostly to increase saving"', add ;
label define qn10 3 `"Mostly to pay off debt"', add ;
label define qn10 4 `"Not sure/dont know"', add ;

label define qn8 1 `"Direct deposit"', modify ;
label define qn8 2 `"Mail"', modify ;
label define qn8 3 `"Dont know"', modify ;

label define qn4 1 `"Yes have funds"', modify ;
label define qn4 2 `"No"', modify ;

label variable qn11_1 "Food, health & beauty aids, and household products" ;
label variable qn11_2 "Entertainment or personal services, such as restaurants, vacations, and movie tickets" ;
label variable qn11_3 "Durable goods such as appliances, electronics and furniture" ;
label variable qn11_4 "Clothing, shoes or accessories" ;
label variable qn11_5 "All other types of purchases" ;

* MAKE REBATE AND IREBATE MONTHLY
    Eg. SET IREBATE TO BE ONE FOR THE WEEK OF AND THREE WEEKS FOLLOWING RECEIPT  ;
sort hhid pperiod ;
gen iesp= (irebate==1 | (irebate==0 & (irebate[_n-1]==1 & hhid==hhid[_n-1]) | 
  (irebate[_n-2]==1 & hhid==hhid[_n-2]) | (irebate[_n-3]==1 & hhid==hhid[_n-3]))) ;
gen esp = iesp*amount ;
drop rebate irebate ;



********************************************************************************
* #2 Summary Stats
******************************************************************************** ;
sort hhid pperiod ;

gen repspending = qn11_1+qn11_2+qn11_3+qn11_4+qn11_5 ;
gen NCPspending = qn11_1 ;
gen nonNCPspending = repspending - NCPspending ;

gen weight=projection_factor ;
gen ispend = spending>0 ;
gen one=1 ;

* Number of observations and households ;
count ;
count if ispend>0 ;
count if hhid~=hhid[_n-1] ;
count if hhid~=hhid[_n-1] & inc2007~=. ;
count if hhid~=hhid[_n-1] & qn4~=. ;
count if hhid~=hhid[_n-1] & repspending~=. ;

* Means, medians, and standard deviations ;
sum projection_factor hhid spending hhsize [aw=weight] ;
statsmat projection_factor hhid spending hhsize [aw=weight], stat(mean median sd n) matrix(stats1) ;

sum spending if ispend>0 [aw=weight] ;
statsmat spending if ispend>0 [aw=weight], stat(mean median sd n) matrix(stats2) ;

sum esp [aw=weight] ;
statsmat esp [aw=weight], stat(mean median sd n) matrix(stats3) ;

*Household level stats ;
sort hhid pperiod ;

sum amount if hhid~=hhid[_n-1] [aw=weight] ;
statsmat amount if hhid~=hhid[_n-1] [aw=weight], stat(mean median sd n) matrix(stats4) ;

gen lowinc = (inc2007<=11)    /* means inc<25K in crosswalk */ ;
gen medinc = (inc2007>11 & inc2007<=19)     /* means 25K<=inc<50K in crosswalk */ ;
gen highinc = (inc2007>=27 & inc2007~=.)   /* mean inc>=100K in crosswalk */ ;
gen upmedinc = 1-lowinc-medinc-highinc ;
gen iinc = 1 if inc2007~=. ;
sum lowinc medinc upmedinc highinc iinc inc2007 if hhid~=hhid[_n-1] & inc2007~=.  [aw=weight] ;
statsmat lowinc medinc upmedinc highinc iinc if hhid~=hhid[_n-1] [aw=weight], stat(mean median sd n) matrix(stats5) ;

gen lowliq = qn4==2 ;
gen highliq= qn4==1 ;
sum qn4 lowliq highliq ;
statsmat qn4 lowliq highliq if hhid~=hhid[_n-1] & (qn4==1 | qn4==2) [aw=weight], stat(mean median sd n) matrix(stats6) ;

gen mostlyspend = qn10==1 ;
gen mostlysave = qn10==2 ;
gen mostlydebt = qn10==3 ;
gen mostlymissing = 0 ;
replace mostlymissing =1 if  qn10==4 | qn10==. ;
sum mostly* if hhid~=hhid[_n-1] & mostlymissing==0 [aw=weight] ;
statsmat mostly* if mostlymissing==0 & hhid~=hhid[_n-1] [aw=weight], stat(mean median sd n) matrix(stats7) ;

gen reportedmpc = repspending/amount ;
sum repspending if hhid~=hhid[_n-1] [aw=weight] ;
statsmat repspending NCPspending nonNCPspending if hhid~=hhid[_n-1] [aw=weight], stat(mean median sd n) matrix(stats8) ;

matrix NCPallstats=(stats1\stats2\stats3\stats4\stats5\stats6\stats7\stats8) ;
matrix list NCPallstats ;

gen mosspend=. ;
replace mosspend=1 if qn10==1 ;
replace mosspend=0 if qn10==2 | qn10==3 ;

* Reported dollar spending by how used ;
table qn10 if hhid~=hhid[_n-1] [aw=weight], c(mean repspending median repspending mean amount median amount) ;
table qn10 if hhid~=hhid[_n-1] [aw=weight], c(mean NCPspending median NCPspending mean nonNCPspending median nonNCPspending) ;
table qn10 if hhid~=hhid[_n-1] [aw=weight], c(mean reportedmpc median reportedmpc n reportedmpc) ;
table mosspend if hhid~=hhid[_n-1] [aw=weight], c(mean NCPspending median NCPspending mean nonNCPspending median nonNCPspending) ;
drop mosspend ;


********************************************************************************
* #3 Prepare for Regressions
******************************************************************************** ;
* MakeLeads of iesp and esp and then lags ;
/**MAKE LEADS HERE**/
sort hhid pperiod ;
local j = 1 ;         /*Number here is number of leads */
local k = `j' ;
while `j'>0 { ; 
    local j4 = 4*`j' ;
    gen byte piesp`j' = . ;
    replace piesp`j' = iesp[_n+`j4'] if hhid==hhid[_n+`j4'] ;
    replace piesp`j' = 0 if pperiod>852-`j4' ; /*set missing at early of year to zero*/
    gen pesp`j' = amount* piesp`j' ;
    local j = `j' - 1 ;
    } ;
assert (iesp~=.)==(piesp1~=.) ;
*assert (iesp~=.)==(piesp2~=.) ;

/**LAGS HERE. SET UP AS 4-WEEK PERIODS
    Number of lags studied should be changed in programs: cumspendreb, cumspendireb 
        and cumpctspendireb**/
local numlags = 8 ;
local studiedlags = 2 ;
sort hhid pperiod ;
* Now make lags 4-week monthly;
local i = 0 ;
while `i'<`numlags' { ;     
    local i = `i' + 1 ;
    local i4 = 4*`i';
    gen byte liesp`i' = 0 ;
    replace liesp`i' = . if iesp==. ;
    replace liesp`i' = iesp[_n-`i4'] if hhid==hhid[_n-`i4'] ;
    replace liesp`i' = 0 if pperiod< 801+`i4' ;
    gen lesp`i' = amount* liesp`i' ;
    } ;

*  KEEP THE FOLLOWING AFTER THE LOOPS OVER i AND DEFINITION OF k ;
table pperiod if sample2, contents(n iesp n liesp`i' n liesp`studiedlags' n piesp`k' ) ;
table pperiod if sample2, contents(sum liesp`i' sum liesp`studiedlags' sum iesp sum piesp`k') ;
egen byte maxlagpperiod = max(pperiod*liesp`studiedlags') if pperiod~=. & sample2 ;
egen byte minleadpperiod = min(pperiod*piesp`k'+1000*(1-piesp`k')) if pperiod~=. & sample2 ;
sum hhid maxlagpperiod minleadpperiod if sample2 ;

** Compare those reporting in the key period ;
gen keyperiod=1-(pperiod>maxlagpperiod |  pperiod<minleadpperiod | pperiod==.) /*Dropped missing pperiod above*/ ;
sum keyperiod pperiod maxlagpperiod minleadpperiod if sample2;
gen Tlengthkeyperiod = maxlagpperiod-minleadpperiod+1 ;
 
compress ;

save ../data/rprpRegs1c, replace ;


** MAKE CONSUMPTION MONTHLY RATE ;
replace spending=4*spending ;


** DROP ALL DATA WE NEVER USE ;    
tab2 qn10 samplerprp, mi co ;
drop if samplerprp~=1 ;
sort hhid pperiod ;



********************************************************************************
* #4 Run Regressions
******************************************************************************** ;
xtset hhid pperiod ;

* Broda Parker paper Table 4 replicate and check 
    similar dropping those without HOWUSED and without valid second lag ;
xtreg spending piesp1 iesp liesp* td* if samplerprp, cluster(hhid) fe ;
xtreg pctspend piesp1 iesp liesp* td* if samplerprp , cluster(hhid) fe;
reghdfe spending td* (pesp1 esp lesp* = piesp1 iesp liesp*) if samplerprp, vce(cluster hhid) absorb(hhid) ;


program lagsum ;
    * input is 
        - 1-3 three variables: esp, lesp1, and l2esp or iesp liesp1 and liesp2 or same with spend, nspend, save or payd
        - 4 one word title for column
        - 5 One word title for table
        - 6 one filename: output file for contemp, lagged and cumulative effects 
        - 7 replace or append ;
    * Calculated distributed lag effects of spending and cumulative spending following regression;
    args 1 2 3 4 5 6 7 ;
    local contemp`1'=_b[`1'] ;     local contemp`1'se=_se[`1'] ; 
    lincom `1'+`2'  ;
    local cum2`1'=r(estimate) ;     local cum2`1'se=r(se) ; 
    lincom `1'+`2'+`3'  ;
    local cum3`1'=r(estimate) ;     local cum3`1'se=r(se) ; 
    outreg2 `1' `2' `3' using `6'.out, bdec(4) se noast ctitle(`4') nocons nolabel `7' title(`5')
        addstat(TestSeqNS,$seqnspvalue,TestSeqNS3,$seqnspvalue3,Contemp,`contemp`1'',SE,_se[`1'],Cum2, `cum2`1'', C2SE, `cum2`1'se',Cum3,`cum3`1'',C3SE, `cum3`1'se') ;
end ;
global seqnspvalue = 0 ;
global seqnspvalue3 = 0 ;

xtreg spending iesp liesp* td* [aw=weight] if samplerprp, cluster(hhid) fe ;
lagsum iesp liesp1 liesp2 Ind Table4 NCPTable4 replace;
xtreg pctspend iesp liesp* td* [aw=weight] if samplerprp, cluster(hhid) fe ;
lagsum  iesp liesp1 liesp2 lInd Table4 NCPTable4 append ;
reghdfe spending td* (esp lesp* = iesp liesp*) [aw=weight] if samplerprp, vce(cluster hhid) absorb(hhid) ;
lagsum esp lesp1 lesp2 NDMPC Table4 NCPTable4 append ;


********************************************************************************
* #5 Revealed Spending by Reported Spending
******************************************************************************** ;
* Set up distributed lags interacted with howused ;
foreach var of varlist esp lesp* iesp liesp* {;
	gen spend`var'= (qn10==1)*`var' ;
	gen nspend`var'= (qn10~=1)*`var' ;
	gen save`var'= (qn10==2)*`var' ;
	gen payd`var'= (qn10==3)*`var' ;
	} ;

* Binary then three-way, structure as in table, nondurable then total ;
program runspendregs ;
  * variable input is word indicating the sample, e.g. all, loqliq, highinc,... ;
  args regsamp ;
  * set samplerprp to the desired sample (clunky programming) ;
  foreach var in spend nspend save payd {;
    local dl`var'esp = "`var'esp `var'lesp1 `var'lesp2" ;
    local dl`var'iesp = "`var'iesp `var'liesp1 `var'liesp2" ;
    local dl`var'espall = "`var'esp `var'lesp*" ;
    local dl`var'iespall = "`var'iesp `var'liesp*" ;
	} ;
  local howspendesp = "`dlspendespall' `dlnspendespall'" ;
  local howusedesp= "`dlspendespall' `dlsaveespall' `dlpaydespall'" ;
  local howspendiesp = "`dlspendiespall' `dlnspendiespall'" ;
  local howusediesp= "`dlspendiespall' `dlsaveiespall' `dlpaydiespall'" ;

  xtreg spending `howspendiesp' td* [aw=weight] if `regsamp', cluster(hhid) fe;
  test spendiesp=nspendiesp ;
  global seqnspvalue=r(p) ;
  test spendiesp+spendliesp1+spendliesp2=nspendiesp+nspendliesp1+nspendliesp2 ;
  global seqnspvalue3=r(p) ;
  lagsum `dlspendiesp' IndSp2 `regsamp'PA NCP`regsamp' replace ;
  lagsum `dlnspendiesp' IndNS `regsamp'PA NCP`regsamp' append ;
  xtreg spending `howusediesp' td* [aw=weight] if `regsamp', cluster(hhid) fe ;
  lagsum `dlsaveiesp' IndSv `regsamp'PA NCP`regsamp' append;
  lagsum `dlpaydiesp' IndPd `regsamp'PA NCP`regsamp' append;
  lagsum `dlspendiesp' IndSp `regsamp'PA NCP`regsamp' append;
    
  xtreg pctspend `howspendiesp' td* [aw=weight] if `regsamp', cluster(hhid) fe ;
  test spendiesp=nspendiesp ;
  global seqnspvalue=r(p) ;
  test spendiesp+spendliesp1+spendliesp2=nspendiesp+nspendliesp1+nspendliesp2 ;
  global seqnspvalue3=r(p) ;
  lagsum `dlspendiesp' lIndSp2 `regsamp'PB NCP`regsamp' append;
  lagsum `dlnspendiesp' lIndNS `regsamp'PB NCP`regsamp' append;
  xtreg pctspend `howusediesp'  td* [aw=weight] if `regsamp', cluster(hhid) fe ;
  lagsum `dlsaveiesp' lIndsv `regsamp'PB NCP`regsamp' append;
  lagsum `dlpaydiesp' lIndPd `regsamp'PB NCP`regsamp' append;
  lagsum `dlspendiesp' lIndSp `regsamp'PB NCP`regsamp' append;
    
  reghdfe spending td* (`howspendesp' = `howspendiesp') [aw=weight] if `regsamp', vce(cluster hhid) absorb(hhid) ;
  test spendesp=nspendesp ;
  global seqnspvalue=r(p) ;
  test spendesp+spendlesp1+spendlesp2=nspendesp+nspendlesp1+nspendlesp2 ;
  global seqnspvalue3=r(p) ;
  lagsum `dlspendesp' MPCSp2 `regsamp'PC NCP`regsamp' append;
  lagsum `dlnspendesp' MPCNS `regsamp'PC NCP`regsamp' append;
  reghdfe spending  td* (`howusedesp' = `howusediesp') [aw=weight] if `regsamp', vce(cluster hhid) absorb(hhid) ;
  lagsum `dlsaveesp' MPCSv `regsamp'PC NCP`regsamp' append;
  lagsum `dlpaydesp' MPCPd `regsamp'PC NCP`regsamp' append;
  lagsum `dlspendesp' MPCSp `regsamp'PC NCP`regsamp' append;
end ;  

assert qn10~=4 & qn10~=. ;
gen allhh=samplerprp ;
runspendregs allhh ;


********************************************************************************
* #6 Income Splits, 2007 Income
******************************************************************************** ;
sort hhid pperiod ;
tab inc2007 [aw=weight] if hhid~=hhid[_n-1] & samplerprp==1, mi ;
* 16 or less = up to 35k (34% of sample), 26+ is 70K+ and is 30% ;
gen income3=. ;
replace income3=1 if inc2007<17 & inc2007~=. ; 
replace income3=2 if inc2007>=17 & inc2007<26 ;
replace income3=3 if  inc2007>=26 & inc2007~=. ;

gen low3inc = income3==1 & samplerprp ;
gen mid3inc = income3==2 & samplerprp ;
gen high3inc = income3==3 & samplerprp ;

ssc install ivreg2 ;
foreach incsample in low3inc mid3inc high3inc { ;
    runspendregs `incsample' ;
    };


********************************************************************************
* #7 Liquid Asset splits, QN4 1= YES HAVE FUNDS, 2 = NO ;
******************************************************************************** ;
sort hhid pperiod ;
tab qn4 [aw=weight] if samplerprp & hhid~=hhid[_n-1], mi ;
gen low2liq = qn4==2 & samplerprp ; 
gen high2liq = qn4==1 & samplerprp ;

ssc install ivreg2 ;
foreach liqsample in low2liq high2liq { ;
    runspendregs `liqsample' ;
    }; 


********************************************************************************
* #8 Tabulate Liquidity and Income with How Used ;
******************************************************************************** ;
gen int intwgt = trunc(weight) ;
sort hhid pperiod ;
drop if weight==. ; 
drop if hhid==hhid[_n-1] ;

gen liq2=.;
replace liq2=0 if low2liq==1 ;
replace liq2=1 if high2liq==1 ;

table qn10 [aw=weight], c(mean repspending median repspending mean amount median amount) ;

program tabhowused ;
*    tab2 income3 qn10, nof row ;
    tab income3 [fw=intwgt] ;
*    tab2 liqassii2 qn10, nof row ;
    tab2 low2liq high2liq [fw=intwgt];
    * Weighted tabulations follow here! ;
    tab2 income3 qn10 [fw=intwgt] if qn10<=3, nof row ;
    tab2 liq2 qn10 [fw=intwgt] if qn10<=3, nof row ;

    table qn10 [fw=intwgt] if qn10<=3 & repspending~=. &  income3~=., c(mean repspending mean amount mean NCPspending) ;
    table income3 [fw=intwgt] if qn10==1 & repspending~=., c(mean repspending mean amount mean NCPspending) ;    
    table income3 [fw=intwgt] if qn10==2 & repspending~=., c(mean repspending mean amount mean NCPspending) ;    
    table income3 [fw=intwgt] if qn10==3 & repspending~=., c(mean repspending mean amount mean NCPspending) ;
    table liq2 [fw=intwgt] if qn10==1 & repspending~=., c(mean repspending mean amount mean NCPspending) ;    
    table liq2 [fw=intwgt] if qn10==2 & repspending~=., c(mean repspending mean amount mean NCPspending) ;    
    table liq2 [fw=intwgt] if qn10==3 & repspending~=., c(mean repspending mean amount mean NCPspending) ;
    table qn10 [fw=intwgt] if qn10<=3 & repspending~=. &  liq2~=., c(mean repspending mean amount mean NCPspending) ;

    sum income3 liq2 hhid if qn10<=3 & qn10~=. & repspending~=. ;
end ;  

log close; 
log using ../log/HowusedTabs.txt, text replace ;

tabhowused;

log close ;
